@@ -1,6 +1,7 @@
 # Copyright DB InfraGO AG and contributors
 # SPDX-License-Identifier: Apache-2.0
 """Implementation of a client providing work item specific functions."""
+
 import json
 import logging
 import typing as t
@@ -18,7 +19,7 @@ from polarion_rest_api_client.open_api_client.api.work_items import (
 )
 
 from . import base_classes as bc
-from . import work_item_attachments, work_item_links
+from . import test_steps, work_item_attachments, work_item_links
 
 WT = t.TypeVar("WT", bound=dm.WorkItem)
 logger = logging.getLogger(__name__)
@@ -26,7 +27,7 @@ if t.TYPE_CHECKING:
     from polarion_rest_api_client import client as polarion_client
 
 
-def _get_json_content_size(data: dict):
+def _get_json_content_size(data: dict) -> int:
     return len(json.dumps(data).encode("utf-8"))
 
 
@@ -49,8 +50,10 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             project_id, client
         )
         self.links = work_item_links.WorkItemLinks(project_id, client)
+        self.test_steps = test_steps.TestSteps(project_id, client)
+        self.item_cls = dm.WorkItem
 
-    def _update(self, to_update: list[dm.WorkItem] | dm.WorkItem):
+    def _update(self, to_update: list[dm.WorkItem] | dm.WorkItem) -> None:
         assert not isinstance(to_update, list), "Expected only one item"
         assert to_update.id is not None
         if to_update.type:
@@ -78,6 +81,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         page_number: int = 1,
         fields: dict[str, str] | None = None,
         work_item_cls: type[WT],
+        revision: str | None = None,
     ) -> tuple[list[WT], bool]:
         """Return the work items on a defined page matching the given query.
 
@@ -95,6 +99,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         page_size: int = 100,
         page_number: int = 1,
         fields: dict[str, str] | None = None,
+        revision: str | None = None,
     ) -> tuple[list[dm.WorkItem], bool]:
         """Return the work items on a defined page matching the given query.
 
@@ -110,7 +115,8 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         page_size: int = 100,
         page_number: int = 1,
         fields: dict[str, str] | None = None,
-        work_item_cls=dm.WorkItem,
+        work_item_cls: type[dm.WorkItem] = dm.WorkItem,
+        revision: str | None = None,
     ) -> tuple[list[dm.WorkItem], bool] | tuple[list[WT], bool]:
         """Return the work items on a defined page matching the given query.
 
@@ -129,6 +135,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             query=query,
             pagesize=page_size,
             pagenumber=page_number,
+            revision=revision or oa_types.UNSET,
         )
 
         self._raise_on_error(response)
@@ -188,7 +195,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
     def get(
         self,
         work_item_id: str,
-        work_item_cls=dm.WorkItem,
+        work_item_cls: type[dm.WorkItem] = dm.WorkItem,
         revision: str | None = None,
     ) -> WT | dm.WorkItem | None:
         """Return one specific work item with all fields.
@@ -224,19 +231,18 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
 
         return None
 
-    def _create(self, items: list[dm.WorkItem]):
+    def _create(self, items: list[dm.WorkItem]) -> None:
         raise NotImplementedError("We have a custom create instead.")
 
-    def create(self, items: dm.WorkItem | list[dm.WorkItem]):
+    def create(self, items: dm.WorkItem | list[dm.WorkItem]) -> None:
         """Create WorkItems and respect the max body size of the server."""
         if not isinstance(items, list):
             items = [items]
         current_batch = api_models.WorkitemsListPostRequest(data=[])
         content_size = min_wi_request_size
         batch_start_index = 0
-        batch_end_index = 0
 
-        for work_item in items:
+        for batch_end_index, work_item in enumerate(items):
             work_item_data = self._build_work_item_post_request(work_item)
 
             (
@@ -272,8 +278,6 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
                 current_batch.data.append(work_item_data)
                 content_size = proj_content_size
 
-            batch_end_index += 1
-
         if current_batch.data:
             self._retry_on_error(
                 self._post_work_item_batch,
@@ -281,7 +285,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
                 items[batch_start_index:],
             )
 
-    def _delete(self, items: list[dm.WorkItem]):
+    def _delete(self, items: list[dm.WorkItem]) -> None:
         work_item_ids = [work_item.id for work_item in items]
         response = delete_work_items.sync_detailed(
             self._project_id,
@@ -289,7 +293,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             body=api_models.WorkitemsListDeleteRequest(
                 data=[
                     api_models.WorkitemsListDeleteRequestDataItem(
-                        type=api_models.WorkitemsListDeleteRequestDataItemType.WORKITEMS,  # pylint: disable=line-too-long
+                        type_=api_models.WorkitemsListDeleteRequestDataItemType.WORKITEMS,  # pylint: disable=line-too-long
                         id=f"{self._project_id}/{work_item_id}",
                     )
                     for work_item_id in work_item_ids
@@ -304,10 +308,10 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         assert work_item.type is not None
 
         attrs = api_models.WorkitemsListPostRequestDataItemAttributes(
-            type=work_item.type,
+            type_=work_item.type,
             description=(
                 api_models.WorkitemsListPostRequestDataItemAttributesDescription(  # pylint: disable=line-too-long
-                    type=api_models.WorkitemsListPostRequestDataItemAttributesDescriptionType(  # pylint: disable=line-too-long
+                    type_=api_models.WorkitemsListPostRequestDataItemAttributesDescriptionType(  # pylint: disable=line-too-long
                         work_item.description.type
                     ),
                     value=work_item.description.value or "",
@@ -322,7 +326,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         attrs.additional_properties.update(work_item.additional_attributes)
 
         return api_models.WorkitemsListPostRequestDataItem(
-            type=api_models.WorkitemsListPostRequestDataItemType.WORKITEMS,
+            type_=api_models.WorkitemsListPostRequestDataItemType.WORKITEMS,
             attributes=attrs,
             # pylint: disable=line-too-long
             relationships=(
@@ -330,7 +334,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
                     module=api_models.WorkitemsListPostRequestDataItemRelationshipsModule(
                         data=api_models.WorkitemsListPostRequestDataItemRelationshipsModuleData(
                             id=f"{self._project_id}/{doc_ref.module_folder}/{doc_ref.module_name}",
-                            type=api_models.WorkitemsListPostRequestDataItemRelationshipsModuleDataType.DOCUMENTS,
+                            type_=api_models.WorkitemsListPostRequestDataItemRelationshipsModuleDataType.DOCUMENTS,
                         ),
                     )
                 )
@@ -354,7 +358,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
 
         if work_item.description is not None:
             attrs.description = api_models.WorkitemsSinglePatchRequestDataAttributesDescription(  # pylint: disable=line-too-long
-                type=api_models.WorkitemsSinglePatchRequestDataAttributesDescriptionType(  # pylint: disable=line-too-long
+                type_=api_models.WorkitemsSinglePatchRequestDataAttributesDescriptionType(  # pylint: disable=line-too-long
                     work_item.description.type
                 ),
                 value=work_item.description.value or "",
@@ -367,7 +371,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
 
         return api_models.WorkitemsSinglePatchRequest(
             data=api_models.WorkitemsSinglePatchRequestData(
-                type=api_models.WorkitemsSinglePatchRequestDataType.WORKITEMS,
+                type_=api_models.WorkitemsSinglePatchRequestDataType.WORKITEMS,
                 id=f"{self._project_id}/{work_item.id}",
                 attributes=attrs,
             )
@@ -377,17 +381,17 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         self,
         work_item_batch: api_models.WorkitemsListPostRequest,
         work_item_objs: list[dm.WorkItem],
-    ):
+    ) -> None:
         response = post_work_items.sync_detailed(
             self._project_id, client=self._client.client, body=work_item_batch
         )
 
         self._raise_on_error(response)
 
-        assert (
-            isinstance(response.parsed, api_models.WorkitemsListPostResponse)
-            and response.parsed.data
+        assert isinstance(
+            response.parsed, api_models.WorkitemsListPostResponse
         )
+        assert response.parsed.data
         for index, work_item_res in enumerate(response.parsed.data):
             assert work_item_res.id
             work_item_objs[index].id = work_item_res.id.split("/")[-1]
@@ -396,7 +400,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         self,
         work_item_data: api_models.WorkitemsListPostRequestDataItem,
         current_content_size: int = min_wi_request_size,
-    ) -> t.Tuple[int, bool]:
+    ) -> tuple[int, bool]:
         work_item_size = _get_json_content_size(work_item_data.to_dict())
 
         proj_content_size = current_content_size + work_item_size
@@ -429,10 +433,13 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         links_truncated = True
         attachments_truncated = True
         if work_item.relationships:
-            if home_document_data := work_item.relationships.module:
-                if home_document_data.data and home_document_data.data.id:
-                    _, folder, name = home_document_data.data.id.split("/")
-                    home_document = dm.DocumentReference(folder, name)
+            if (
+                (home_document_data := work_item.relationships.module)
+                and home_document_data.data
+                and home_document_data.data.id
+            ):
+                _, folder, name = home_document_data.data.id.split("/")
+                home_document = dm.DocumentReference(folder, name)
 
             if link_data := work_item.relationships.linked_work_items:
                 if (
@@ -443,7 +450,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
 
                 links = [
                     self.links._parse_work_item_link(
-                        link.id,
+                        link.id or "",
                         link.additional_properties.get("suspect", False),
                         work_item_id,
                     )
@@ -470,7 +477,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         description = None
         if work_item.attributes.description:
             description = dm.TextContent(
-                self.unset_to_none(work_item.attributes.description.type),
+                self.unset_to_none(work_item.attributes.description.type_),
                 self.unset_to_none(work_item.attributes.description.value),
             )
 
@@ -478,7 +485,7 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             work_item_id,
             title=self.unset_to_none(work_item.attributes.title),
             description=description,
-            type=self.unset_to_none(work_item.attributes.type),
+            type=self.unset_to_none(work_item.attributes.type_),
             status=self.unset_to_none(work_item.attributes.status),
             additional_attributes=work_item.attributes.additional_properties,
             linked_work_items=links,
