@@ -20,7 +20,7 @@ def fixture_client():
         polarion_access_token="PAT123",
         batch_size=3,
     )
-    yield client.generate_project_client(
+    return client.generate_project_client(
         project_id="PROJ", delete_status="deleted"
     )
 
@@ -133,6 +133,24 @@ TEST_TREC_NO_NEXT_RESPONSE = TEST_RESPONSES / "test_records_no_next_page.json"
 TEST_TRUN_NEXT_RESPONSE = TEST_RESPONSES / "test_runs_next_page.json"
 TEST_TRUN_NO_NEXT_RESPONSE = TEST_RESPONSES / "test_runs_no_next_page.json"
 
+TEST_STEPS_CREATED_RESPONSE = TEST_RESPONSES / "created_test_steps.json"
+TEST_STEPS_NEXT_RESPONSE = TEST_RESPONSES / "test_steps_next_page.json"
+TEST_STEPS_NO_NEXT_RESPONSE = TEST_RESPONSES / "test_steps_no_next_page.json"
+TEST_STEPS_PATCH_REQUEST = TEST_REQUESTS / "patch_test_steps.json"
+TEST_STEPS_POST_REQUEST = TEST_REQUESTS / "post_test_steps.json"
+
+TEST_TRUN_PARAM_NEXT_RES = TEST_RESPONSES / "get_test_run_parameter.json"
+TEST_TRUN_PARAM_NO_NEXT_RES = (
+    TEST_RESPONSES / "get_test_run_parameter_no_next.json"
+)
+TEST_TRUN_PARAM_CREATED_RES = (
+    TEST_RESPONSES / "created_test_parameters_trun.json"
+)
+TEST_TRUN_PARAM_CREATED_REQ_1 = TEST_REQUESTS / "create_parameters_trun_1.json"
+TEST_TRUN_PARAM_CREATED_REQ_2 = TEST_REQUESTS / "create_parameters_trun_2.json"
+TEST_TRUN_PARAM_DELETE_REQ_1 = TEST_REQUESTS / "delete_parameters_trun_1.json"
+TEST_TRUN_PARAM_DELETE_REQ_2 = TEST_REQUESTS / "delete_parameters_trun_2.json"
+
 
 class CustomWorkItem(polarion_api.WorkItem):
     capella_uuid: str | None
