@@ -29,12 +29,12 @@ def test_get_test_runs_multi_page(
     with open(TEST_TRUN_NO_NEXT_RESPONSE, encoding="utf8") as f:
         httpx_mock.add_response(json=json.load(f))
 
-    test_runs = client.test_runs.get_all("123", fields={"test_runs": "@all"})
+    test_runs = client.test_runs.get_all("123", fields={"testruns": "@all"})
 
     query = {
         "page[size]": "100",
         "page[number]": "1",
-        "fields[test_runs]": "@all",
+        "fields[testruns]": "@all",
         "query": "123",
     }
     reqs = httpx_mock.get_requests()
@@ -72,7 +72,7 @@ def test_create_test_runs(
         "open",
         "Title",
         polarion_api.TextContent("text/html", "My text value"),
-        datetime.datetime.utcfromtimestamp(0),
+        datetime.datetime.fromtimestamp(0, datetime.timezone.utc),
         "Group ID",
         "ID Prefix",
         True,
@@ -88,7 +88,7 @@ def test_create_test_runs(
         "open",
         "Title",
         polarion_api.TextContent("text/html", "My text value 2"),
-        datetime.datetime.utcfromtimestamp(0),
+        datetime.datetime.fromtimestamp(0, datetime.timezone.utc),
         "Group ID",
         "ID Prefix",
         True,
@@ -123,7 +123,7 @@ def test_update_test_run(
         "manual",
         "passed",
         "Title",
-        finished_on=datetime.datetime.utcfromtimestamp(0),
+        finished_on=datetime.datetime.fromtimestamp(0, datetime.timezone.utc),
         query="Query",
         use_report_from_template=False,
     )
@@ -151,7 +151,7 @@ def test_update_test_run_fully(
         "open",
         "Title",
         polarion_api.TextContent("text/html", "My text value"),
-        datetime.datetime.utcfromtimestamp(0),
+        datetime.datetime.fromtimestamp(0, datetime.timezone.utc),
         "Group ID",
         "ID Prefix",
         True,
