@@ -21,9 +21,36 @@ from tests.conftest import (
 )
 
 
+@pytest.mark.parametrize(
+    ("revision", "query"),
+    [
+        (
+            None,
+            {
+                "fields[linkedworkitems]": "id,role",
+                "page[size]": "100",
+                "page[number]": "1",
+                "include": "workitem",
+            },
+        ),
+        (
+            "12345",
+            {
+                "fields[linkedworkitems]": "id,role",
+                "page[size]": "100",
+                "page[number]": "1",
+                "include": "workitem",
+                "revision": "12345",
+            },
+        ),
+    ],
+    ids=["no_revision", "with_revision"],
+)
 def test_get_work_item_links_single_page(
     client: polarion_api.ProjectClient,
     httpx_mock: pytest_httpx.HTTPXMock,
+    revision: str | None,
+    query: dict,
 ):
     with open(
         TEST_WIL_NO_NEXT_PAGE_RESPONSE,
@@ -35,14 +62,9 @@ def test_get_work_item_links_single_page(
         "MyWorkItemId",
         include="workitem",
         fields={"fields[linkedworkitems]": "id,role"},
+        revision=revision,
     )
 
-    query = {
-        "fields[linkedworkitems]": "id,role",
-        "page[size]": "100",
-        "page[number]": "1",
-        "include": "workitem",
-    }
     reqs = httpx_mock.get_requests()
     assert reqs[0].method == "GET"
     assert dict(reqs[0].url.params) == query
@@ -83,7 +105,7 @@ def test_get_work_item_links_multi_page(
     assert dict(reqs[1].url.params) == query
     assert len(work_items) == 2
     assert len(reqs) == 2
-    assert work_items[0].suspect is False
+    assert work_items[0].suspect is None
 
 
 def test_delete_work_item_link(
@@ -100,7 +122,8 @@ def test_delete_work_item_link(
 
     req = httpx_mock.get_request()
 
-    assert req is not None and req.method == "DELETE"
+    assert req is not None
+    assert req.method == "DELETE"
     with open(TEST_WIL_DELETED_REQUEST, encoding="utf8") as f:
         assert json.loads(req.content.decode()) == json.load(f)
 
@@ -124,7 +147,8 @@ def test_delete_work_item_links(
 
     req = httpx_mock.get_request()
 
-    assert req is not None and req.method == "DELETE"
+    assert req is not None
+    assert req.method == "DELETE"
     with open(TEST_WIL_DELETE_REQUEST, encoding="utf8") as f:
         expected_request = json.load(f)
 
@@ -178,7 +202,8 @@ def test_create_work_item_link(
 
     req = httpx_mock.get_request()
 
-    assert req is not None and req.method == "POST"
+    assert req is not None
+    assert req.method == "POST"
     assert req.url.path.endswith("PROJ/workitems/MyWorkItemId/linkedworkitems")
     with open(TEST_WIL_POSTED_REQUEST, encoding="utf8") as f:
         expected = json.load(f)
@@ -251,7 +276,8 @@ def test_create_work_item_links_same_primaries(
 
     req = httpx_mock.get_request()
 
-    assert req is not None and req.method == "POST"
+    assert req is not None
+    assert req.method == "POST"
     with open(TEST_WIL_MULTI_POST_REQUEST, encoding="utf8") as f:
         expected = json.load(f)
 
